Struct trackable::error::Failure [−][src]
pub struct Failure(_);
TrackableError type specialized for Failed.
Methods
impl Failure[src]
impl Failurepub fn from_error<E>(error: E) -> Self where
E: Into<BoxError>, [src]
pub fn from_error<E>(error: E) -> Self where
E: Into<BoxError>, Makes a new Failure instance which was caused by the error.
Methods from Deref<Target = TrackableError<Failed>>
pub fn kind(&self) -> &K[src]
pub fn kind(&self) -> &KReturns the kind of this error.
pub fn concrete_cause<T>(&self) -> Option<&T> where
T: Error + 'static, [src]
pub fn concrete_cause<T>(&self) -> Option<&T> where
T: Error + 'static, Tries to return the cause of this error as a value of T type.
If neither this error has a cause nor it is an T value,
this method will return None.